
c     The program "nc_dimensions" performs the following actions:
c      *reads a netCDF file which has a name given as input either
c        during run time, or by directing input through an ASCII file
c      *determines wheter the horizontal grid is lon-by-lat or x-by-y
c      *reads the x,y,t dimensional sizes; and the z, z_ice sizes (if
c        present, otherwise, these are set to 0)
c      *writes the dimensional sizes, and flag use/non-use of
c        spherical coordinates on the file "nc_dims.inc"


      program nc_dimensions

      implicit none

      include 'netcdf.inc'

c     Variables:
      integer nc_id,x_id,y_id,lon_id,lat_id,z_id,z_ice_id,time_id
      integer nx,ny,nz,nz_ice,nt,nc_status,size,sphere_on
      character*120 filelist,filename

c     Function:
      integer str_len


c     Read file name from 2nd line:
      read(5,*)
      read(5,'(a120)')filename

c     Open netCDF file:
      size = str_len(filename)
      nc_status = NF_OPEN(filename(1:size), NF_NOWRITE, nc_id)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,0)

c     Find dimension/ x,y or lon,lat:
      nc_status = NF_INQ_DIMID(nc_id, 'x', x_id)
      if (nc_status .ne. NF_NOERR) then
         nc_status = NF_INQ_DIMID(nc_id, 'lon', lon_id)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,11)
         nc_status = NF_INQ_DIMLEN(nc_id, lon_id, nx)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,12)
         nc_status = NF_INQ_DIMID(nc_id, 'lat', lat_id)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,13)
         nc_status = NF_INQ_DIMLEN(nc_id, lat_id, ny)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,14)
         sphere_on = 1
      else
         nc_status = NF_INQ_DIMLEN(nc_id, x_id, nx)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,21)
         nc_status = NF_INQ_DIMID(nc_id, 'y', y_id)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,22)
         nc_status = NF_INQ_DIMLEN(nc_id, y_id, ny)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,23)
         sphere_on = 0
      end if

c     Find dimension/ z:
      nc_status = NF_INQ_DIMID(nc_id, 'z', z_id)
      if (nc_status .ne. NF_NOERR) then
         nz = 0
      else
         nc_status = NF_INQ_DIMLEN(nc_id, z_id, nz)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,5)
      end if

c     Find dimension/ z_ice:
      nc_status = NF_INQ_DIMID(nc_id, 'z_ice', z_ice_id)
      if (nc_status .ne. NF_NOERR) then
         nz_ice = 0
      else
         nc_status = NF_INQ_DIMLEN(nc_id, z_ice_id, nz_ice)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,5)
      end if

c     Find dimension/ time:
      nc_status = NF_INQ_DIMID(nc_id, 'time', time_id)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,5)
      nc_status = NF_INQ_DIMLEN(nc_id, time_id, nt)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,6)

      open(31, file= 'nc_dims.inc', status= 'unknown',
     >         access= 'sequential', form= 'formatted')

 101  format(6x,a26)
      write(31,101)'integer nx,ny,nz,nz_ice,nt'

 102  format(6x,a15,i4,a6,i4,a6,i2,a10,i2,a6,i4,a1)
      write(31,102)'parameter (nx= ',nx,', ny= ',ny,', nz= ',nz,
     >             ', nz_ice= ',nz_ice,', nt= ',nt,')'

 103  format(6x,a17)
      write(31,103)'integer sphere_on'

 104  format(6x,a22,i1,a1)
      write(31,104)'parameter (sphere_on= ',sphere_on,')'

      nc_status = NF_CLOSE(nc_id)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,99)

      open(41, file= 'ok_flag', status='unknown')
      close(41)

      end
