
c     #################
c     #  1. SWITCHES  #
c     #################


      integer temp_on,temp_K_on,salt_on,sgm_t_on,
     >        sst_on,sst_K_on,sss_on,thck_on,
     >        u_on,v_on,vol_x_on,vol_y_on,
     >        ice_frac_on,ice_thck_on,
     >        u_ice_on,v_ice_on,vol_x_ice_on,vol_y_ice_on,
     >        ssh_on,topo_on,sphere_on,
     >        climatology_on,climate_dates_on

c     Set switches for declaration of variables in netCDF files:
c      0 - do not include this variable
c      1 - include this variable

      data temp_on       / 0 /  ! Temperature
      data temp_K_on     / 0 /  ! Temperature (Kelvin)
      data salt_on       / 0 /  ! Salinity
      data sgm_t_on      / 0 /  ! Sigma-t (density)
      data sst_on        / 0 /  ! Sea surface temperature
      data sst_K_on      / 0 /  ! Sea surface temperature (Kelvin)
      data sss_on        / 0 /  ! Sea surface salinity
      data thck_on       / 0 /  ! Layer thickness
      data u_on          / 0 /  ! Velocity-x
      data v_on          / 0 /  ! Velocity-y
      data vol_x_on      / 0 /  ! Volume flux-x (layers)
      data vol_y_on      / 0 /  ! Volume flux-y (layers)
      data ice_frac_on   / 0 /  ! Ice cover (fraction)
      data ice_thck_on   / 0 /  ! Ice thickness
      data u_ice_on      / 0 /  ! Ice velocity-x
      data v_ice_on      / 0 /  ! Ice velocity-y
      data vol_x_ice_on  / 0 /  ! Ice volume flux-x
      data vol_y_ice_on  / 0 /  ! Ice volume flux-y
      data ssh_on        / 0 /  ! Sea surface height
      data topo_on       / 0 /  ! Bottom topography


c     Set switch for horizontal grid:
c      0 - do not use spherical grid
c      1 - spherical grid, use latitude/longitude as x,y-coordinates

      data sphere_on     / 0 /

c     NOTE!
c          If "sphere is on"  (i.e., 'sphere_on' is set to 1), the arrays
c           that hold the longitudes and latitudes are ONE-dimensional.
c          If "sphere is off" (i.e., 'sphere_on' is set to 0), the arrays
c           that hold the longitudes and latitudes are TWO-dimensional.


c     Set switch for including headers for climatological fields:
      data climatology_on / 1 /


c     Set switch for using dates of "climate years":
c      0 - Use usual dates, including leap years
c      1 - Use "climate years", i.e., 12 months of 30 days in all years

      data climate_dates_on / 0 /

c     NOTE!
c          If the time units used is 'years' or 'months', this switch will
c          be overridden, as use of "climate years" will be forced.
c          See "3. DOMAIN, TIME" below for specification of 'timeunit'.



c     #############################
c     #  2. OFFSET, SCALE FACTOR  #
c     #############################


      real level_offset,ice_level_offset,
     >     temp_offset,temp_K_offset,salt_offset,sgm_t_offset,
     >     sst_offset,sst_K_offset,sss_offset,thck_offset,
     >     u_offset,v_offset,vol_x_offset,vol_y_offset,
     >     ice_frac_offset,ice_thck_offset,
     >     u_ice_offset,v_ice_offset,vol_x_ice_offset,vol_y_ice_offset,
     >     ssh_offset,

     >     level_scale,ice_level_scale,
     >     temp_scale,temp_K_scale,salt_scale,sgm_t_scale,
     >     sst_scale,sst_K_scale,sss_scale,thck_scale,
     >     u_scale,v_scale,vol_x_scale,vol_y_scale,
     >     ice_frac_scale,ice_thck_scale,
     >     u_ice_scale,v_ice_scale,vol_x_ice_scale,vol_y_ice_scale,
     >     ssh_scale

c     Set offset and scale factors for variables that should be
c     represented by real numbers, but will be stored as
c     (2 byte) integers.
c      [ real number = scale factor * integer number + offset ]
c     NOTE: * 'ice_level_offset', 'ice_level_scale' will
c             (probably) not be used, and their values are not important
c           * 'level_offset', 'level_scale' will (probably)
c             not be used when 'leveltype' is 1 (i.e., layers)

      data level_offset      / 0. /    ! Vertical level
      data level_scale       / 1. /
      data ice_level_offset  / 0. /    ! Vertical level, ice
      data ice_level_scale   / 1. /
      data temp_offset       / 0. /    ! Temperature
      data temp_scale        / 0.01 /
      data temp_K_offset     / 273.15 / ! Temperature (Kelvin)
      data temp_K_scale      / 0.01 /
      data salt_offset       / 0. /     ! Salinity
      data salt_scale        / 0.01 /
      data sgm_t_offset      / 0. /     ! Sigma-t (density)
      data sgm_t_scale       / 0.01 /
      data sst_offset        / 0. /     ! Sea surface temperature
      data sst_scale         / 0.01 /
      data sst_K_offset      / 273.15 / ! Sea surface temperature (Kelvin)
      data sst_K_scale       / 0.01 /
      data sss_offset        / 0. /     ! Sea surface salinity
      data sss_scale         / 0.01 /
      data thck_offset       / 0. /     ! Layer thickness
      data thck_scale        / 0.1 /
      data u_offset          / 0. /     ! Velocity-x
      data u_scale           / 0.001 /
      data v_offset          / 0. /     ! Velocity-y
      data v_scale           / 0.001 /
      data vol_x_offset      / 0. /     ! Volume flux-x (layers)
      data vol_x_scale       / 0.1 /
      data vol_y_offset      / 0. /     ! Volume flux-y (layers)
      data vol_y_scale       / 0.1 /
      data ice_frac_offset   / 0. /     ! Ice cover (fraction)
      data ice_frac_scale    / 0.001 /
      data ice_thck_offset   / 0. /     ! Ice thickness
      data ice_thck_scale    / 0.001 /
      data u_ice_offset      / 0. /     ! Ice velocity-x
      data u_ice_scale       / 0.001 /
      data v_ice_offset      / 0. /     ! Ice velocity-y
      data v_ice_scale       / 0.001 /
      data vol_x_ice_offset  / 0. /     ! Ice volume flux-x
      data vol_x_ice_scale   / 0.001 /
      data vol_y_ice_offset  / 0. /     ! Ice volume flux-y
      data vol_y_ice_scale   / 0.001 /
      data ssh_offset        / 0. /     ! Sea surface height
      data ssh_scale         / 0.001 /



c     #####################
c     #  3. DOMAIN, TIME  #
c     #####################


      integer nx,ny,nz,nz_ice,leveltype


c     Domain dimensions:

      parameter (nx= 1, ny= 1, nz= 1)     ! (x,y,z)-dimensions ('nz' may be 0)
      parameter (nz_ice= 0)               ! z-dimension for ice (may be 0)


c     Type of vertical coordinate used for 'nz' (not used when 'nz' is 0):
c      1 - layers
c      2 - positive z-levels (bottom: z=H)
c      3 - negative z-levels (bottom: z=-H)
c      4 - negative sigma levels (fraction of depth)
c      5 - negative sigma levels (fraction of depth)

      parameter (leveltype= 1)


c     Specification of vertical resolution:
c      'leveltype' values
c      ^^^^^^^^^^^ ^^^^^^
c      1           layer no.s
c      2, 3        position of z-levels,     in meters
c      4, 5        position of sigma-levels, in fractions of bottom depth

      real levels(max(1,nz)),ice_levels(max(1,nz_ice))
      data levels      / 0. /  ! Levels for 'nz'
      data ice_levels  / 0. /  ! Levels for 'nz_ice'

c     Time variables:

      integer reference_date(6), timestep(6)
      character*7 timeunit
      character*20 timemethod

c     Format:             / year, month, day, hour, minute, second /
      data reference_date / 2000, 1, 1, 0, 0, 0 /  ! For computation of time
c      example for 'timestep': 36 hours should be / 0, 0, 1, 12, 0, 0 /
      data timestep       /    0, 0, 0, 0, 0, 0 /  ! Time between sets

c     Format/ timeunit: one of
c      'years', 'months', 'days', hours', 'minutes', 'seconds'
      data timeunit       / '' /         ! Unit for offset time values

c     Format/ timemethod: one of
c      'averaged', 'interpolated', 'sampled', 'unknown'
      data timemethod     / '' /         ! Extraction method



c     #####################
c     #  4. GENERAL INFO  #
c     #####################


      character*120 filename

c     Name of (output) netCDF file:
      data filename / '' /


      character*120 title, source, method, reference, web_reference,
     >              history, author, email

c     Length of line
c234567                                                               72
c     |                                                                |
c     v                                                                v

c     Descriptive title of information set:
      data title
     >   / ' ' /

c     Source of information set (organization):
      data source
     >   / ' ' /

c     Method applied for obtaining the information set
c      (ftp address, tape, e-mail etc.):
      data method
     >   / ' ' /

c     Publication which describes the information set
c      (paper, report etc.):
      data reference
     >   / ' ' /

c     http-address to web_site where the information set is described:
      data web_reference
     >   / ' ' /

c     Information set history (date, version no. etc.):
      data history
     >   / ' ' /

c     Responsible NOClim scientist:
      data author
     >   / ' ' /

c     e-mail address to 'author':
      data email
     >   / ' ' /

c     ^                                                                ^
c     |                                                                |
c234567                                                               72
c     Length of line
