
ccc   Subroutine on "end_dates.f":
ccc    set_end_dates    - updates the earliest or latest date,
ccc                       if appropriate
ccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


c     ********************
c     General description:
c     ********************

c     The subroutine "set_end_dates" updates the earliest date if the
c     specified date precedes the previously earliest date,
c     or updates the latest date if the specified date succeeds the
c     latest date. If the flag for existence of such "end dates" is
c     off, the specified date is stored as both the ealiest and the
c     latest date.



c     ***********************
c     Input/output variables:
c     ***********************

c      date           (iA) - input date to check, format:
c                             date(1) - year
c                             date(2) - month
c                             date(3) - day
c                             date(4) - hour
c                             date(5) - minute
c      seconds        (r)  - output, seconds to add to date
c      climate_dates  (l)  - switch, if (.true.) use "climate years"
c                             (12 months with 30 days in each month);
c                             if (.false.) use calendar years
c      got_date       (l)  - switch, if (.true.), previous
c                             'first_date()', 'last_date()' have been
c                             identified;
c                             if (.false.), neither has been
c                             identified, but will be set now, and
c                             'got_date' will be set to (.true.)
c      first_date     (iA) - previously earliest date, will be updated
c                             if appropriate;
c                             format: see 'date()' above
c      first_sec      (r)  - seconds for the earliest date
c      last_date      (iA) - previously latest date, will be updated
c                             if appropriate;
c                             format: see 'date()' above
c      last_sec       (r)  - seconds for the latest date


c     Above:
c      iA - integer array    [ 4 byte, aka. "long" ]
c      r  - real             [ 4 byte, aka. "float" ]
c      l  - logical          [ (.false.)/0 or (.true.)/nonzero ]


      subroutine set_end_dates(date,sec,climate_dates,got_date,
     >                         first_date,first_sec,last_date,last_sec)

      implicit none

c     Input:
      integer date(5)
      real sec
      logical climate_dates

c     Input/output:
      logical got_date
      integer first_date(5),last_date(5)
      real first_sec,last_sec

c     Local:
      integer i,d_time(3)
      real d_sec


      if (got_date) then

c        Is the present date the earliest so far?
         call diff_time(climate_dates,first_date,first_sec,date,sec,
     >                  d_time,d_sec)
         if (d_time(1) .lt. 0 .or. d_time(2) .lt. 0 .or.
     >       d_time(3) .lt. 0 .or. d_sec .lt. 0.) then
c           Yes, reset 'first_date':
            do i = 1,5
               first_date(i) = date(i)
            end do
            first_sec = sec
         end if

c        Is the present date the latest so far?
         call diff_time(climate_dates,date,sec,last_date,last_sec,
     >                  d_time,d_sec)
         if (d_time(1) .lt. 0 .or. d_time(2) .lt. 0 .or.
     >       d_time(3) .lt. 0 .or. d_sec .lt. 0.) then
c           Yes, reset 'last_date':
            do i = 1,5
               last_date(i) = date(i)
            end do
            last_sec = sec
         end if

      else

c        First date encountered,
c        set 'first_date'/'first_sec', 'last_date'/'last_sec':
         do i = 1,5
            first_date(i) = date(i)
            last_date(i) = date(i)
         end do
         first_sec = sec
         last_sec = sec
         got_date = .true.

      end if


      return
      end
